
***********************************************************************************
* Environment set up
***********************************************************************************
clear
set more off
cap log close

* Set main data path (depending on where you want to work with the downloaded data)
global dir_main "C:\YOUR_DATA_FOLDER"

* Specify subfolders
	*Input files
	global dir_input "input" // please put your downloaded data here

	*Output files	
	global dir_graphs "graphs"
	
	*Temporary files
	global dir_temp "temp"
	
	
* Make directories
cap mkdir ${dir_main}
cap mkdir ${dir_main}\\${dir_input}
cap mkdir ${dir_main}\\${dir_graphs}
cap mkdir ${dir_main}\\${dir_temp}

*Go to the working directory
cd "${dir_main}"

***********************************************************************************
* Replicate Figure V for Apple (page 551 of QJE paper)
* QJE paper: “Currency Unions, Product Introductions, and the Real Exchange Rate” by Cavallo, Neiman, and
*Rigobon, Quarterly Journal of Economics, 2014
***********************************************************************************

**Input files (saved in input folder)
*CNR_QJE_apple.dta
*exchange_long.dta

***Output files
**Data files （saved in temp folder）
*exchange_long_es.dta

**Graph files (saved in graphs folder)
*hist_<country>.pdf (where country in the list: at dk de fi fr ie it nl no pt se us)
*hist_all.pdf (a pdf combining all the country hist graphs)

*Load the price data
use ${dir_input}\\CNR_QJE_apple.dta, clear

*Merge exchange rates data
gen country_string=country
merge m:1 date country_string using ${dir_input}\\exchange_long.dta, keep(1 3) nogen

*Obtain Spain's exchange rate with usd (usd per euro) -----> usdeur
preserve
use ${dir_input}\\exchange_long.dta, clear
keep if country=="es" //es represents Spain
ren usdx usdeur
save ${dir_temp}\\exchange_long_es.dta, replace
restore

*Now add each country X's exchange rate with usd (usd per current X) ------> usdx
merge m:1 date using ${dir_temp}\\exchange_long_es.dta, keepusing(usdeur) keep(1 3) nogen

*Obtain each country X's bilateral exchange rate with the Euro (current X per euro) -------> xeur
gen xeur=usdeur/usdx

*calculate the good level real exchange rate q via equation in section 3 (q=lnpi-lne-lnpj, where ln means log)
**lnpi
gen lnpi=ln(price)
**lne
gen lne=ln(xeur)
**lnpj
gen lnpj0=lnpi if country=="es" //es represents Spain
bysort date id: egen lnpj=max(lnpj0)
drop lnpj0
**calculate q
gen q=lnpi-lne-lnpj

*Drop outliers
gen absq=abs(q)
drop if absq>=0.75

*Loop to create graphs for required countries
local listcountry = "at dk de fi fr ie it nl no pt se us"
local listgraph = ""

foreach country in `listcountry' {
if "`country'" == "at" {
local countryname = "Austria"
}
if "`country'" == "dk" {
local countryname = "Denmark"
}
if "`country'" == "de" {
local countryname = "Germany"
}
if "`country'" == "fi" {
local countryname = "Finland"
}
if "`country'" == "fr" {
local countryname = "France"
}
if "`country'" == "ie" {
local countryname = "Ireland"
}
if "`country'" == "it" {
local countryname = "Italy"
}
if "`country'" == "nl" {
local countryname = "Netherlands"
}
if "`country'" == "no" {
local countryname = "Norway"
}
if "`country'" == "pt" {
local countryname = "Portugal"
}
if "`country'" == "se" {
local countryname = "Sweden"
}
if "`country'" == "us" {
local countryname = "USA"
}
hist q if country=="`country'", bin(100) ///
percent ///
color(gs1) ///
title("`countryname'", size(medsmall)) ///
xtitle(" ") ///
ytitle(" ") ///
xlabel(-0.75(0.25)0.75) ///
name(hist_`country', replace) ///
graphregion(fcolor(white))  
graph export ${dir_graphs}\\hist_`country'.pdf , replace
local listgraph "`listgraph' hist_`country'"
}

*Combined Graphs
graph combine `listgraph', ///
graphregion(fcolor(white)) 
graph export ${dir_graphs}\\hist_all.pdf , replace
